@@ -238,17 +238,23 @@ class QolsysDB:
         return zones
 
     def get_powerg(self, short_id: str) -> dict:
+        try:
+            self.cursor.execute(f"SELECT * FROM {self.table_powerg_device.table} WHERE shortID = ?",(short_id,))
+            self.db.commit()
 
-        self.cursor.execute(f"SELECT * FROM {self.table_powerg_device} WHERE shortID = ?",short_id)
-        row = self.cursor.fetchone()
+            row = self.cursor.fetchone()
 
-        if row is None:
-            LOGGER.debug("%s value not found", short_id)
+            if row is None:
+                LOGGER.debug("%s value not found", short_id)
+                return None
+
+            columns = [description[0] for description in self.cursor.description]
+            return  dict(zip(columns, row, strict=True))
+
+        except sqlite3.Error:
+            LOGGER.exception("Error getting PowerG device info for shortID %s", short_id)
             return None
 
-        columns = [description[0] for description in self.cursor.description]
-        return  dict(zip(columns, row, strict=True))
-
 
     def get_setting_panel(self, setting: str) -> str:
         self.cursor.execute(f"""SELECT value FROM {self.table_qolsyssettings.table}
